cinnamon: update to 4.2.4

This commit is contained in:
mobinmob 2019-09-26 20:53:23 +03:00 committed by Helmut Pozimski
parent 73ae13443a
commit 4ceedfaa9f
4 changed files with 5 additions and 110 deletions

View file

@ -1,64 +0,0 @@
From 595178cf57b80b977401460a147602832157b303 Mon Sep 17 00:00:00 2001
From: Eli Schwartz <eschwartz93@gmail.com>
Date: Fri, 5 Apr 2019 11:28:45 -0400
Subject: [PATCH] PIL: remove unnnecessary version check and code fork (#8496)
The Image.VERSION variable was deprecated some time ago and is now gone
entirely. But its only use was to determine whether we were using at
least the latest version of PIL, or any version of its fork, Pillow. And
PIL was last developed in 2009 and does not support python3 at all, so
we are guaranteed to be using Pillow.
Moreover, the check does not really matter, as Pillow is guaranteed to
load any image it opens, without the user doing so manually.
Fixes #8495
---
.../cinnamon/cinnamon-settings/bin/imtools.py | 27 +------------------
1 file changed, 1 insertion(+), 26 deletions(-)
diff --git a/files/usr/share/cinnamon/cinnamon-settings/bin/imtools.py b/files/usr/share/cinnamon/cinnamon-settings/bin/imtools.py
index 05605001f7..c386fe3847 100644
--- files/usr/share/cinnamon/cinnamon-settings/bin/imtools.py
+++ files/usr/share/cinnamon/cinnamon-settings/bin/imtools.py
@@ -620,31 +620,6 @@ def has_transparency(image):
has_alpha(image)
-if Image.VERSION == '1.1.7':
-
- def split(image):
- """Work around for bug in Pil 1.1.7
-
- :param image: input image
- :type image: PIL image object
- :returns: the different color bands of the image (eg R, G, B)
- :rtype: tuple
- """
- image.load()
- return image.split()
-else:
-
- def split(image):
- """Work around for bug in Pil 1.1.7
-
- :param image: input image
- :type image: PIL image object
- :returns: the different color bands of the image (eg R, G, B)
- :rtype: tuple
- """
- return image.split()
-
-
def get_alpha(image):
"""Gets the image alpha band. Can handles P mode images with transpareny.
Returns a band with all values set to 255 if no alpha band exists.
@@ -655,7 +630,7 @@ def get_alpha(image):
:rtype: single band image object
"""
if has_alpha(image):
- return split(image)[-1]
+ return image.split()[-1]
if image.mode == 'P' and 'transparency' in image.info:
return image.convert('RGBA').split()[-1]
# No alpha layer, create one.

View file

@ -1,25 +0,0 @@
From 36af45f699daa886a3c3fc3187e0b24b193294ad Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Ball=C3=B3=20Gy=C3=B6rgy?= <ballogyor@gmail.com>
Date: Sat, 22 Nov 2014 22:39:39 +0100
Subject: [PATCH] Set default theme to 'cinnamon'
---
data/org.cinnamon.gschema.xml.in | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/data/org.cinnamon.gschema.xml.in b/data/org.cinnamon.gschema.xml.in
index 91fa171..9f56e4c 100644
--- data/org.cinnamon.gschema.xml.in
+++ data/org.cinnamon.gschema.xml.in
@@ -581,7 +581,7 @@
<schema id="org.cinnamon.theme" path="/org/cinnamon/theme/"
gettext-domain="@GETTEXT_PACKAGE@">
<key name="name" type="s">
- <default>""</default>
+ <default>"cinnamon"</default>
<_summary>Theme name</_summary>
<_description>
The name of the theme
--
2.1.3

View file

@ -1,17 +0,0 @@
--- files/usr/share/cinnamon/cinnamon-settings-users/cinnamon-settings-users.py.orig 2017-12-18 13:53:18.000000000 +0100
+++ files/usr/share/cinnamon/cinnamon-settings-users/cinnamon-settings-users.py 2017-12-21 22:15:03.058109278 +0100
@@ -839,11 +833,11 @@
pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size("/usr/share/cinnamon/faces/user-generic.png", 48, 48)
description = "<b>%s</b>\n%s" % (fullname, username)
piter = self.users.append(None, [new_user, pixbuf, description])
# Add the user to his/her own group and sudo if Administrator was selected
if dialog.account_type_combo.get_active() == 1:
- subprocess.call(["usermod", username, "-G", "%s,sudo,nopasswdlogin" % username])
+ subprocess.call(["usermod", username, "-G", "%s,wheel,nopasswdlogin" % username])
else:
- subprocess.call(["usermod", username, "-G", "%s,nopasswdlogin" % username])
+ subprocess.call(["usermod", username, "-G", "%s" % username])
self.load_groups()
dialog.destroy()

View file

@ -1,7 +1,7 @@
# Template file for 'cinnamon'
pkgname=cinnamon
version=4.0.10
revision=2
version=4.2.4
revision=1
build_style=gnu-configure
configure_args="--disable-static --disable-schemas-compile
--enable-compile-warnings=no --disable-gtk-doc"
@ -18,14 +18,15 @@ depends=" accountsservice caribou cinnamon-settings-daemon>=${version%.*}
cinnamon-translations>=${version%.*} nemo>=${version%.*}
gnome-themes-standard gnome-themes-standard-metacity gnome-backgrounds
network-manager-applet polkit-gnome upower>=0.99.7 libkeybinder3 python3-dbus
@@ -839,11 +833,11 @@
description = "<b>%s</b>\n%s" % (fullname, username)
piter = self.users.append(None, [new_user, pixbuf, description])
- # Add the user to his/her own group and sudo if Administrator was selected
+ # Add the user to his/her own group and wheel if Administrator was selected
if dialog.account_type_combo.get_active() == 1:
python3-gobject python3-pam python3-pexpect python3-Pillow python3-inotify"
python3-gobject python3-pam python3-pexpect python3-Pillow python3-inotify
python3-tinycss"
short_desc="GNOME3 fork of Linux Mint with GNOME2 aspect"
maintainer="Orphaned <orphan@voidlinux.org>"
license="GPL-2.0-or-later, LGPL-2.0-or-later"
homepage="http://developer.linuxmint.com/projects/cinnamon-projects.html/"
changelog="https://raw.githubusercontent.com/linuxmint/Cinnamon/${version}/debian/changelog"
distfiles="https://github.com/linuxmint/${pkgname}/archive/${version}.tar.gz"
checksum=50e07fa014eeecb380e840a3be0f09c8af0ad368c64c6b8ce6c30b1f78a2bf66
checksum=4329b03e08a82316b6890b761174132c18a349508387f005748c32436f6364fd
nocross="gobject-introspection"
pycompile_version="$py3_ver"